jQuery(document).ready(function($) {
    const uploadZone = $('#boxmoe-upload-zone');
    const fileInput = $('#boxmoe-file-input');
    const previewContainer = $('#upload-preview');

    uploadZone.on('dragover', function(e) {
        e.preventDefault();
        e.stopPropagation();
        $(this).css('border-color', '#0073aa');
    });

    uploadZone.on('dragleave', function(e) {
        e.preventDefault();
        e.stopPropagation();
        $(this).css('border-color', '#ddd');
    });

    uploadZone.on('drop', function(e) {
        e.preventDefault();
        e.stopPropagation();
        $(this).css('border-color', '#ddd');
        
        const files = e.originalEvent.dataTransfer.files;
        handleFiles(files);
    });

    fileInput.on('change', function() {
        handleFiles(this.files);
    });

    function handleFiles(files) {
        Array.from(files).forEach(file => {
            if (!file.type.startsWith('image/')) {
                alert('只能上传图片文件！');
                return;
            }

            const preview = createPreviewElement(file);
            uploadFile(file, preview);
        });
    }

    function createPreviewElement(file) {
        const reader = new FileReader();
        const wrapper = $('<div class="preview-card">');
        const previewItem = $('<div class="preview-item">');
        const img = $('<img class="preview-image">');
        const status = $('<div class="upload-status">').text('准备上传...');
        const progressBar = $('<div class="progress-bar"><div class="progress"></div></div>');

        reader.onload = function(e) {
            img.attr('src', e.target.result);
        };
        reader.readAsDataURL(file);

        previewItem.append(img);
        wrapper.append(previewItem)
               .append(status)
               .append(progressBar);
        $('.preview-content').prepend(wrapper); 

        return wrapper;
    }

    function uploadFile(file, previewElement) {
        const formData = new FormData();
        formData.append('user_id', boxmoeUploaderParams.user_id);
        formData.append('auth_token', boxmoeUploaderParams.token);
        formData.append('file', file);

        $.ajax({
            url: boxmoeUploaderParams.api_url,
            type: 'POST',
            data: formData,
            processData: false,
            contentType: false,
            xhr: function() {
                const xhr = new window.XMLHttpRequest();
                xhr.upload.addEventListener('progress', function(e) {
                    if (e.lengthComputable) {
                        const percent = Math.round((e.loaded / e.total) * 100);
                        previewElement.find('.status').text(`上传中 ${percent}%`);
                        previewElement.find('.progress').css('width', `${percent}%`);
                    }
                }, false);
                return xhr;
            },
            success: function(response) {
                if (response.code === 200) {
                    previewElement.find('.upload-status').text('上传成功').addClass('success');
                    previewElement.find('.progress-bar').addClass('complete');
                    
                    let imageUrl = response.img_url;
                    if (boxmoeUploaderParams.use_baidu_proxy === '1') {
                        imageUrl = 'https://image.baidu.com/search/down?url=' + imageUrl;
                    }
                    
                    const urlFormats = {
                        'URL': imageUrl,
                        'HTML': `<img src="${imageUrl}" alt="image">`,
                        'Markdown': `![image](${imageUrl})`
                    };
                    
                    const copyButtonsContainer = $('<div class="copy-actions">');
                    
                    Object.entries(urlFormats).forEach(([format, text]) => {
                        const copyBtn = $('<button class="copy-btn">')
                            .html(`<span class="dashicons dashicons-clipboard"></span> ${format}`)
                            .on('click', function() {
                                navigator.clipboard.writeText(text);
                                $(this).addClass('copied');
                                setTimeout(() => $(this).removeClass('copied'), 2000);
                            });
                        copyButtonsContainer.append(copyBtn);
                    });
                    
                    previewElement.append(copyButtonsContainer);
                } else {
                    previewElement.find('.upload-status').text(`上传失败: ${response.message}`).addClass('error');
                    previewElement.find('.progress-bar').addClass('error');
                }
            },
            error: function(xhr, status, error) {
                previewElement.find('.upload-status').text(`上传失败: ${error}`).addClass('error');
                previewElement.find('.progress-bar').addClass('error');
            }
        });
    }

    $('#clear-preview').on('click', function() {
        $('.preview-content').empty();
    });

    $('#toggle-settings').on('click', function() {
        const $settingsForm = $('#settings-form');
        const $icon = $(this).find('.dashicons');
        
        if ($settingsForm.is(':visible')) {
            $settingsForm.slideUp(300);
            $icon.removeClass('dashicons-arrow-up-alt2').addClass('dashicons-arrow-down-alt2');
        } else {
            $settingsForm.slideDown(300);
            $icon.removeClass('dashicons-arrow-down-alt2').addClass('dashicons-arrow-up-alt2');
        }
    });
});