<?php
/**
 * Plugin Name: BoxMoe图床上传器
 * Plugin URI: https://www.boxmoe.com
 * Description: 一个简单的BoxMoe图床上传插件
 * Version: 1.0.0
 * Author: BoxmoeUPimg_plugin
 * Author URI: https://www.boxmoe.com
 * License: GPL2
 */

// 防止直接访问
if (!defined('ABSPATH')) {
    exit;
}

function boxmoe_uploader_menu() {
    add_menu_page(
        '图床API上传',
        '图床API上传',
        'manage_options',
        'boxmoe-uploader',
        'boxmoe_uploader_page',
        'dashicons-upload'
    );
}
add_action('admin_menu', 'boxmoe_uploader_menu');

function boxmoe_uploader_settings() {
    register_setting('boxmoe_uploader_options', 'boxmoe_api_url');
    register_setting('boxmoe_uploader_options', 'boxmoe_use_baidu_proxy');
}
add_action('admin_init', 'boxmoe_uploader_settings');

function boxmoe_uploader_scripts() {
    wp_enqueue_script('boxmoe-uploader', plugins_url('js/uploader.js', __FILE__), array('jquery'), '1.0.0', true);
    wp_enqueue_style('boxmoe-uploader', plugins_url('css/uploader.css', __FILE__));
    
    wp_localize_script('boxmoe-uploader', 'boxmoeUploaderParams', array(
        'ajaxurl' => admin_url('admin-ajax.php'),
        'nonce' => wp_create_nonce('boxmoe_uploader_nonce'),
        'api_url' => get_option('boxmoe_api_url'),
        'user_id' => get_option('boxmoe_user_id'),
        'token' => get_option('boxmoe_token'),
        'use_baidu_proxy' => get_option('boxmoe_use_baidu_proxy', '0')
    ));
}
add_action('admin_enqueue_scripts', 'boxmoe_uploader_scripts');

function boxmoe_uploader_page() {
    ?>
    <div class="wrap boxmoe-dashboard-wrapper">
        <div class="boxmoe-dashboard-header">
            <h1><span class="dashicons dashicons-cloud-upload"></span> boxmoeUPimg图床API上传</h1>
            <div class="header-actions">
                <span class="version-badge">v1.0.0</span>
            </div>           
        </div>
        <p>这个是<a href="https://www.boxmoe.com/706.html" target="_blank">boxmoeUPimg</a>图床的插件，可以接入API上传图片到图床，并获取图片的URL，HTML，Markdown格式。</p>
        <div class="boxmoe-dashboard-grid">
            <div class="dashboard-card settings-panel">
                <div class="card-header">
                    <h2><span class="dashicons dashicons-admin-generic"></span> 基础设置</h2>
                    <button id="toggle-settings" class="toggle-btn">
                        <span class="dashicons dashicons-arrow-down-alt2"></span>
                    </button>
                </div>
                <div id="settings-form" class="card-content">
                    <form method="post" action="options.php">
                        <?php settings_fields('boxmoe_uploader_options'); ?>
                        <div class="form-grid">
                            <div class="form-group">
                                <label>API地址</label>
                                <input type="text" name="boxmoe_api_url" 
                                       value="<?php echo esc_attr(get_option('boxmoe_api_url')); ?>" 
                                       class="regular-text">
                                <p class="description">请输入完整的API地址，在BoxMoe图床用户中心API里面创建</p>
                            </div>
                            <div class="form-group switch-group">
                                <label>使用百度图片代理</label>
                                <div class="switch-wrapper">
                                    <label class="switch">
                                        <input type="checkbox" name="boxmoe_use_baidu_proxy" 
                                               value="1" <?php checked(get_option('boxmoe_use_baidu_proxy'), '1'); ?>>
                                        <span class="slider round"></span>
                                    </label>
                                    <span class="switch-label">启用百度图片代理</span>
                                </div>
                            </div>
                        </div>
                        <div class="form-actions">
                            <?php submit_button('保存设置', 'primary button-hero', 'submit', false, array('id' => 'submit-btn')); ?>
                        </div>
                    </form>
                </div>
            </div>

            <div class="dashboard-card uploader-panel">
                <div class="card-header">
                    <h2><span class="dashicons dashicons-upload"></span> 图片上传</h2>
                </div>
                <div class="card-content">
                    <div id="boxmoe-upload-zone" class="upload-zone">
                        <input type="file" id="boxmoe-file-input" accept="image/*" multiple>
                        <div class="upload-hint">
                            <span class="dashicons dashicons-cloud-upload"></span>
                            <h3>拖拽上传</h3>
                            <p>点击或拖拽图片到此处上传</p>
                            <div class="upload-formats">支持 JPG、PNG、GIF 等格式</div>
                        </div>
                    </div>
                </div>
            </div>

            <div class="dashboard-card history-panel">
                <div class="card-header">
                    <h2><span class="dashicons dashicons-images-alt2"></span> 上传历史</h2>
                    <button id="clear-preview" class="clear-btn">
                        <span class="dashicons dashicons-trash"></span> 清除历史
                    </button>
                </div>
                <div class="preview-content card-content"></div>
            </div>
        </div>
    </div>
    <?php
}